package main

import (
	"flow"
	"flow/registry"
	"flowserver"
	"flowserver/cmd/flowserver/floatops"
	"fmt"
	"io"
	"log"
	"time"

	"github.com/gohxs/prettylog"
)

func main() {
	prettylog.Global()
	log.Println("Running version:", flowserver.Version)

	floatops.Register(registry.Global)

	registry.Add(customStruct, setName, setURL).Categories("test-struct")

	registry.Batch{registry.Register("stream", stream)}.Categories("streamer")

	registry.Batch{
		registry.Register("wait", wait),
	}.Categories("time-test").
		Extra("style", map[string]string{
			"color": "#8a5",
		})

	addr := ":2015"
	log.Println("Starting server  at:", ":2015")

	f := flowserver.FlowServer{}
	f.ListenAndServe(addr)
}

func wait(data flow.Data, n int) flow.Data {
	time.Sleep(time.Duration(n) * time.Second) // Simulate
	return data
}

func stream(w io.Writer, val interface{}) interface{} {
	fmt.Fprint(w, val)
	return val
}

// CustomStruct testing custom struct passing
type CustomStruct struct {
	Name string
	Url  string
}

func customStruct() CustomStruct {
	return CustomStruct{}
}
func setName(a CustomStruct, name string) CustomStruct {
	a.Name = name
	return a
}
func setURL(a CustomStruct, url string) CustomStruct {
	a.Url = url
	return a
}
